# 格子 (xlwings)

#### 介绍
python xlwings 的草蟒中文版，提供强大易用的 Office 电子表格处理功能

#### 安装教程

`python -m pip install -U grasspy-xlwings`

#### 使用说明

```python
# 一个简单示例

导入 格子

>>> 工作簿 = 格子.〇工作簿()   # 创建一个新工作簿
>>> 工作表 = 工作簿.工作表々['Sheet1']   # 获取一个工作表对象

>>> 工作表.范围('A1').值 = '姓名'
>>> 工作表.范围('A1').值
'姓名'

>>> 工作表.范围('A1').值 = [['小美', '小刚', '小王'], [10.0, 20.0, 30.0]]
>>> 工作表.范围('A1').扩展().值
[['小美', '小刚', '小王'], [10.0, 20.0, 30.0]]
```

